// IBM Confidential OCO Source Material
// 5724-J34 (C) COPYRIGHT International Business Machines Corp. 2009
// The source code for this program is not published or otherwise divested
// of its trade secrets, irrespective of what has been deposited with the
// U.S. Copyright Office.

package com.ibm.websphere.batch;

import com.ibm.ws.longrun.CGJob;

/**
 * This api enables a Batch Step EJB to retrieve a handle to a Batch Data Stream at runtime.
 *
 * @ibm-api
 */

public class BatchDataStreamMgr {


    protected BatchDataStreamMgr() {}

    /**
     * Returns a BatchDataStream object for the Batch Data Stream identified by its logical name and the
     * id of the job and step with which it is associated. 
     * 
     * The id is composed of the jobid and stepid, separated by a forward slash.  The helper class 
     * JobStepID whose constructor accepts a jobid and stepid creates an id in the required format.
     * 
     * This method is called by a Batch Step EJB to get a handle to the Batch Data Stream
     * implementation and to read/write data to that stream.
     *
     * @throws BatchContainerDataStreamException if an error is encountered retrieving the BatchDataStream object
     *  
     * @param logicalname logical name of the Batch Data Stream
     * @param jobidStepid id composed of the jobid and stepid, separated by a forward slash (e.g. PostingsSampleEar:181/Step1)
     * 
     * @return  The BatchDataStream implementation for the Batch Data Stream identified by the 
     * the logical name and jobid stepid combination.
     *
     */

    public static BatchDataStream getBatchDataStream( String logicalname, String jobidStepid ) 
    throws BatchContainerDataStreamException
    {    
        return BatchDataStreamConfigMgr.getBatchDataStreamConfigMgr().getBatchDataStream( logicalname, jobidStepid );
    }

    public static BatchDataStream getBatchDataStream(CGJob job, String logicalname, String jobidStepid ) 
    throws BatchContainerDataStreamException
    {    
        return BatchDataStreamConfigMgr.getBatchDataStreamConfigMgr().getBatchDataStream(job, logicalname, jobidStepid );
    }

    
    public Object clone() throws CloneNotSupportedException 
    {
        throw new CloneNotSupportedException();
    }

}
